# coding: utf-8

import re


class URLegendarium(object):

    def __init__(self, acron='', year_pub='', volume='', number='',
                 fpage='', lpage='', article_id='', suppl_number=''):

        self.acron = acron
        self.year_pub = str(year_pub)
        self.volume = volume
        self.number = number
        self.suppl_number = suppl_number
        self.fpage = fpage
        self.lpage = lpage
        self.article_id = article_id

    def __unicode__(self):
        return self.url_article

    def __str__(self):
        return self.url_article

    def __repr__(self):
        return self.url_article

    def _get_numbers(self, text):
        """
        Get just numbers in a text.
        """
        if text:
            return re.sub("[^0-9]", "", text)
        else:
            return ''

    def _clean_year_pub(self):
        """
        Clean the year removing all caracter and keep just 4/1 numbers.
        """
        if self.year_pub:
            year = self._get_numbers(self.year_pub)
            if len(year) == 4:
                return '{0}'.format(year[:4])
            else:
                raise ValueError(u'Probably not a valid year')
        else:
            return u''

    def _clean_volume(self):
        """
        Clean the volume removing all caracter and keep just numbers.
        """
        return self._get_numbers(self.volume)

    def _clean_number(self):
        """
        Clean the number stripped the beginning and the end of the string.
        """
        if self.number:
            return self.number.strip()
        else:
            return ''

    def _clean_acron(self):
        """
        Clean the title stripped the beginning and the end of the string.
        """
        return self.acron.strip()

    def _clean_suppl_number(self):
        """
        Clean the supplement number stripped the beginning and the end of the string.
        """
        if self.suppl_number:
            return self.suppl_number.strip()
        else:
            return ''

    def get_journal_seg(self):
        """
        Method to build the journal URL.
        """
        if self.acron:
            title = self._clean_acron()
        else:
            raise ValueError(u'The journal is mandatory to mount the URL')

        return u'{0}'.format(title)

    def get_issue_seg(self):
        """
        Method to build the issue.
        """
        year = self._clean_year_pub()
        volume = self._clean_volume()
        number = self._clean_number()
        suppl = self._clean_suppl_number()

        if suppl:
            suppl = u'suppl{0}'.format(suppl)

        if number:
            number = u'n{0}'.format(number)

        if volume:
            volume = u'v{0}'.format(volume)

        if year:
            year = u'{0}'.format(year)

        if year or volume or number or suppl:
            # We give preference to number
            return u'{0}.{1}{2}{3}'.format(year, volume, number, suppl)
        else:
            raise ValueError(u'Year or Volume or Year must exists to form URL Issue Segment')

    def get_article_seg(self):
        """
        Method to build the article.
        """
        article = u''

        if self.article_id:
            article = self.article_id
        elif self.fpage and self.lpage:
            article = u'{0}-{1}'.format(self.fpage, self.lpage)
        elif self.fpage:
            article = self.fpage
        elif self.lpage:
            article = self.lpage
        else:
            return article

        return u'{0}'.format(article)

    @property
    def url_journal(self):
        """
        Print the url follow the basic definition:

            REVISTA/
        """
        args = [self.get_journal_seg()]

        return u'{0}/'.format(*args)

    @property
    def url_issue(self):
        """
        Print the url follow the basic definition:

            REVISTA/nVOLUMEvNUMBER
        """
        args = [self.get_journal_seg(), self.get_issue_seg()]

        return u'{0}/{1}'.format(*args)

    @property
    def url_article(self):
        """
        Print the url follow the basic definition:

            REVISTA/nVOLUMEvNUMBER/e1928639
        """
        args = [self.get_journal_seg(), self.get_issue_seg(), self.get_article_seg()]

        return u'{0}/{1}/{2}'.format(*args)



# coding: utf-8
import unittest

from legendarium.urlegendarium import URLegendarium


class TestLegendarium(unittest.TestCase):

    def setUp(self):
        self.dict_leg = {'acron': u'spm',
                         'year_pub': u'2011',
                         'volume': u'67',
                         'number': u'9',
                         'suppl_number': u'3',
                         'fpage': u'154',
                         'lpage': u'200',
                         'article_id': u'e00120416'
                         }

    def test_build_url_journal_with_all_param(self):
        leg = URLegendarium(**self.dict_leg)

        self.assertEqual(u'spm/', leg.url_journal)

    def test_build_url_issue_with_all_param(self):
        del(self.dict_leg['suppl_number'])  # Remove the suppl_number

        leg = URLegendarium(**self.dict_leg)

        self.assertEqual(u'spm/2011.v67n9', leg.url_issue)

    def test_build_url_article_with_all_param(self):
        del(self.dict_leg['suppl_number'])  # Remove the suppl_number
        leg = URLegendarium(**self.dict_leg)

        self.assertEqual(u'spm/2011.v67n9/e00120416', leg.url_article)

    def test_build_url_article_without_eloaction_param(self):
        del(self.dict_leg['suppl_number'])  # Remove the suppl_number
        del(self.dict_leg['article_id'])

        leg = URLegendarium(**self.dict_leg)

        self.assertEqual(u'spm/2011.v67n9/154-200', leg.url_article)

    def test_build_url_article_without_fpage_param(self):
        del(self.dict_leg['suppl_number'])  # Remove the suppl_number
        del(self.dict_leg['article_id'])
        del(self.dict_leg['fpage'])

        leg = URLegendarium(**self.dict_leg)

        self.assertEqual(u'spm/2011.v67n9/200', leg.url_article)

    def test_build_url_article_without_lpage_param(self):
        del(self.dict_leg['suppl_number'])  # Remove the suppl_number
        del(self.dict_leg['article_id'])
        del(self.dict_leg['lpage'])

        leg = URLegendarium(**self.dict_leg)

        self.assertEqual(u'spm/2011.v67n9/154', leg.url_article)

    def test_build_url_journal_without_acron_param(self):

        del(self.dict_leg['acron'])  # Remove the acron

        leg = URLegendarium(**self.dict_leg)

        self.assertRaises(ValueError, lambda: leg.url_journal)

    def test_build_url_issue_without_year_vol_num_param(self):

        del(self.dict_leg['year_pub'])  # Remove the year_pub
        del(self.dict_leg['volume'])  # Remove the volume
        del(self.dict_leg['number'])  # Remove the number
        del(self.dict_leg['suppl_number'])  # Remove the suppl_number

        leg = URLegendarium(**self.dict_leg)

        self.assertRaises(ValueError, lambda: leg.url_issue)

    def test_build_url_issue_supplment_volume(self):

        del(self.dict_leg['number'])  # Remove the number

        leg = URLegendarium(**self.dict_leg)

        self.assertEqual(u'spm/2011.v67suppl3', leg.url_issue)

    def test_build_url_issue_supplment_number(self):

        leg = URLegendarium(**self.dict_leg)

        self.assertEqual(u'spm/2011.v67n9suppl3', leg.url_issue)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8
import unittest

from legendarium.formatter import (
    CitationFormatter,
    short_format,
    very_short_format,
    descriptive_format,
    descriptive_short_format,
    descriptive_very_short_format,
    descriptive_html_format,
    descriptive_html_short_format,
    descriptive_html_very_short_format,
    get_numbers
)


class TestLegendarium(unittest.TestCase):

    def setUp(self):
        self.sample = {
            'title': u'Revista Mal-Estar Subjetivo',
            'short_title': u'Rev.Mal-Estar Subj',
            'pubdate': u'2011',
            'volume': u'67',
            'number': u'9',
            'fpage': u'154',
            'lpage': u'200',
            'elocation': u'e00120416',
            'suppl': u'3'
        }

        self.legendarium = CitationFormatter(**self.sample)

    def test_format(self):

        result = self.legendarium.format('%T, %Y, %v(%n), %p')

        self.assertEqual(
            'Revista Mal-Estar Subjetivo, 2011, 67(9), 154-200',
            result
        )

    def test_very_short_format(self):

        del(self.sample['title'])
        del(self.sample['short_title'])
        del(self.sample['fpage'])
        del(self.sample['lpage'])
        del(self.sample['elocation'])
        result = very_short_format(**self.sample)

        self.assertEqual(
            '2011, 67(9) suppl. 3',
            result
        )

    def test_very_short_format_1(self):

        del(self.sample['title'])
        del(self.sample['short_title'])
        del(self.sample['fpage'])
        del(self.sample['lpage'])
        del(self.sample['elocation'])

        self.sample['suppl'] = ''

        result = very_short_format(**self.sample)

        self.assertEqual(
            '2011, 67(9)',
            result
        )

    def test_very_short_format_2(self):

        del(self.sample['title'])
        del(self.sample['short_title'])
        del(self.sample['fpage'])
        del(self.sample['lpage'])
        del(self.sample['elocation'])

        self.sample['suppl'] = ''

        result = very_short_format(**self.sample)

        self.assertEqual(
            '2011, 67(9)',
            result
        )

    def test_very_short_format_3(self):

        del(self.sample['title'])
        del(self.sample['short_title'])
        del(self.sample['fpage'])
        del(self.sample['lpage'])
        del(self.sample['elocation'])

        self.sample['suppl'] = ''
        self.sample['number'] = ''

        result = very_short_format(**self.sample)

        self.assertEqual(
            '2011, 67',
            result
        )

    def test_very_short_format_4(self):

        del(self.sample['title'])
        del(self.sample['short_title'])
        del(self.sample['fpage'])
        del(self.sample['lpage'])
        del(self.sample['elocation'])

        self.sample['number'] = ''

        result = very_short_format(**self.sample)

        self.assertEqual(
            '2011, 67 suppl. 3',
            result
        )

    def test_very_short_format_5(self):

        del(self.sample['title'])
        del(self.sample['short_title'])
        del(self.sample['fpage'])
        del(self.sample['lpage'])
        del(self.sample['elocation'])

        self.sample['volume'] = ''

        result = very_short_format(**self.sample)

        self.assertEqual(
            '2011, (9) suppl. 3',
            result
        )

    def test_very_short_format_6(self):

        del(self.sample['title'])
        del(self.sample['short_title'])
        del(self.sample['fpage'])
        del(self.sample['lpage'])
        del(self.sample['elocation'])

        self.sample['suppl'] = ''
        self.sample['volume'] = ''

        result = very_short_format(**self.sample)

        self.assertEqual(
            '2011, (9)',
            result
        )

    def test_short_format(self):

        data = dict(self.sample)
        del(data['fpage'])
        del(data['lpage'])
        del(data['elocation'])
        result = short_format(**data)

        self.assertEqual(
            'Rev.Mal-Estar Subj, 2011 67(9) suppl 3',
            result
        )

    def test_short_format_suppl_volume(self):

        data = {
            'title': 'Revista de Odontologia da Universidade de São Paulo',
            'short_title': 'Rev. Odontol. Univ. São Paulo',
            'pubdate': '1997',
            'volume': '11',
            'number': '',
            'suppl': '1'
        }

        result = short_format(**data)

        self.assertEqual(
            'Rev. Odontol. Univ. São Paulo, 1997 11 suppl 1',
            result

        )

    def test_short_format_suppl_number(self):

        data = {
            'title': 'Revista de Odontologia da Universidade de São Paulo',
            'short_title': 'Rev. Odontol. Univ. São Paulo',
            'pubdate': '1997',
            'volume': '11',
            'number': '21',
            'suppl': '1'
        }

        result = short_format(**data)

        self.assertEqual(
            'Rev. Odontol. Univ. São Paulo, 1997 11(21) suppl 1',
            result

        )

    def test_short_format_suppl_number_1(self):

        data = {
            'title': 'Revista de Odontologia da Universidade de São Paulo',
            'short_title': 'Rev. Odontol. Univ. São Paulo',
            'pubdate': '1997',
            'volume': '11',
            'number': '21',
            'suppl': '0'
        }

        result = short_format(**data)

        self.assertEqual(
            'Rev. Odontol. Univ. São Paulo, 1997 11(21) suppl',
            result

        )

    def test_short_format_suppl_volume_1(self):

        data = {
            'title': 'Revista de Odontologia da Universidade de São Paulo',
            'short_title': 'Rev. Odontol. Univ. São Paulo',
            'pubdate': '1997',
            'volume': '11',
            'number': '',
            'suppl': '0'
        }

        result = short_format(**data)

        self.assertEqual(
            'Rev. Odontol. Univ. São Paulo, 1997 11 suppl',
            result

        )

    def test_descriptive_format(self):

        result = descriptive_format(**self.sample)

        self.assertEqual(
            'Revista Mal-Estar Subjetivo, 2011, Volume: 67, Number: 9 Supplement 3, Article number: e00120416',
            result
        )

    def test_descriptive_format_1(self):

        self.sample['elocation'] = ''

        result = descriptive_format(**self.sample)

        self.assertEqual(
            'Revista Mal-Estar Subjetivo, 2011, Volume: 67, Number: 9 Supplement 3, Pages: 154-200',
            result
        )

    def test_descriptive_format_number_only(self):

        data = {
            'title': 'Cadernos Pagu ',
            'short_title': 'Cad. Pagu',
            'pubdate': '2017',
            'volume': '',
            'number': '50',
            'suppl': '',
            'fpage': '',
            'lpage': '',
            'elocation': 'e175002'
        }

        result = descriptive_format(**data)

        self.assertEqual(
            'Cadernos Pagu, 2017, Number: 50, Article number: e175002',
            result

        )

    def test_descriptive_format_suppl_number(self):

        data = {
            'title': 'Revista de Odontologia da Universidade de São Paulo',
            'short_title': 'Rev. Odontol. Univ. São Paulo',
            'pubdate': '1997',
            'volume': '11',
            'number': '21',
            'suppl': '1',
            'fpage': '121',
            'lpage': '143',
            'elocation': ''
        }

        result = descriptive_format(**data)

        self.assertEqual(
            'Revista de Odontologia da Universidade de São Paulo, 1997, Volume: 11, Number: 21 Supplement 1, Pages: 121-143',
            result

        )

    def test_descriptive_format_suppl_number_1(self):

        data = {
            'title': 'Revista de Odontologia da Universidade de São Paulo',
            'short_title': 'Rev. Odontol. Univ. São Paulo',
            'pubdate': '1997',
            'volume': '11',
            'number': '21',
            'suppl': '0',
            'fpage': '121',
            'lpage': '143',
            'elocation': ''
        }

        result = descriptive_format(**data)

        self.assertEqual(
            'Revista de Odontologia da Universidade de São Paulo, 1997, Volume: 11, Number: 21 Supplement, Pages: 121-143',
            result

        )

    def test_descriptive_format_suppl_volume(self):

        data = {
            'title': 'Revista de Odontologia da Universidade de São Paulo',
            'short_title': 'Rev. Odontol. Univ. São Paulo',
            'pubdate': '1997',
            'volume': '11',
            'number': '',
            'suppl': '1',
            'fpage': '121',
            'lpage': '143',
            'elocation': ''
        }

        result = descriptive_format(**data)

        self.assertEqual(
            'Revista de Odontologia da Universidade de São Paulo, 1997, Volume: 11 Supplement 1, Pages: 121-143',
            result

        )

    def test_descriptive_format_suppl_volume_1(self):

        data = {
            'title': 'Revista de Odontologia da Universidade de São Paulo',
            'short_title': 'Rev. Odontol. Univ. São Paulo',
            'pubdate': '1997',
            'volume': '11',
            'number': '',
            'suppl': '0',
            'fpage': '121',
            'lpage': '143',
            'elocation': ''
        }

        result = descriptive_format(**data)

        self.assertEqual(
            'Revista de Odontologia da Universidade de São Paulo, 1997, Volume: 11 Supplement, Pages: 121-143',
            result

        )

    def test_descriptive_short_format(self):

        del(self.sample['elocation'])
        del(self.sample['fpage'])
        del(self.sample['lpage'])

        result = descriptive_short_format(**self.sample)

        self.assertEqual(
            'Revista Mal-Estar Subjetivo, 2011, Volume: 67, Number: 9 Supplement 3',
            result
        )

    def test_descriptive_html_format(self):

        result = descriptive_html_format(**self.sample)

        self.assertEqual(
            '<div class="biblio_label"><span class="title">Revista Mal-Estar Subjetivo</span><span class="year">2011</span><span class="prefix volume">Volume:</span> <span class="value volume">67</span><span class="prefix number">Number:</span> <span class="value number">9</span><span class="prefix supplement">Supplement</span> <span class="value supplement">3</span><span class="prefix pages">Article number:</span> <span class="value pages">e00120416</span></div>',
            result
        )

    def test_descriptive_html_short_format(self):

        del(self.sample['elocation'])
        del(self.sample['fpage'])
        del(self.sample['lpage'])

        result = descriptive_html_short_format(**self.sample)

        self.assertEqual(
            '<div class="biblio_label"><span class="title">Revista Mal-Estar Subjetivo</span><span class="year">2011</span><span class="prefix volume">Volume:</span> <span class="value volume">67</span><span class="prefix number">Number:</span> <span class="value number">9</span><span class="prefix supplement">Supplement</span> <span class="value supplement">3</span></div>',
            result
        )

    def test_descriptive_very_short_format(self):

        del(self.sample['title'])
        del(self.sample['short_title'])
        del(self.sample['lpage'])
        del(self.sample['fpage'])
        del(self.sample['elocation'])

        result = descriptive_very_short_format(**self.sample)

        self.assertEqual(
            '2011, Volume: 67, Number: 9 Supplement 3',
            result
        )

    def test_descriptive_html_very_short_format(self):

        del(self.sample['title'])
        del(self.sample['short_title'])
        del(self.sample['lpage'])
        del(self.sample['fpage'])
        del(self.sample['elocation'])

        result = descriptive_html_very_short_format(**self.sample)

        self.assertEqual(
            '<div class="biblio_label"><span class="year">2011</span><span class="prefix volume">Volume:</span> <span class="value volume">67</span><span class="prefix number">Number:</span> <span class="value number">9</span><span class="prefix supplement">Supplement</span> <span class="value supplement">3</span></div>',
            result
        )

    def test_pages(self):
        result = self.legendarium.pages

        self.assertEqual(
            '154-200',
            result
        )

    def test_pages_1(self):

        del(self.sample['fpage'])

        result = CitationFormatter(**self.sample).pages

        self.assertEqual(
            '200',
            result
        )

    def test_pages_2(self):

        del(self.sample['lpage'])

        result = CitationFormatter(**self.sample).pages

        self.assertEqual(
            '154',
            result
        )

    def test_pages_3(self):

        del(self.sample['fpage'])
        del(self.sample['lpage'])

        result = CitationFormatter(**self.sample).pages

        self.assertEqual(
            'e00120416',
            result
        )

    def test_pages_3(self):

        del(self.sample['fpage'])
        del(self.sample['lpage'])
        del(self.sample['elocation'])

        result = CitationFormatter(**self.sample).pages

        self.assertEqual(
            '',
            result
        )

    def test_get_numbers_1(self):

        result = get_numbers('v22')

        self.assertEqual('22', result)

    def test_get_numbers_2(self):

        result = get_numbers('vol. 22.')

        self.assertEqual('22', result)

    def test_get_numbers_3(self):

        result = get_numbers('vol.')

        self.assertEqual('', result)

    def test_build_raw_format(self):
        result = self.legendarium.rawformat

        self.assertEqual(
            'Revista Mal-Estar Subjetivo, Rev.Mal-Estar Subj, 2011, 67, 9, 3, 154, 200, e00120416',
            result
        )



# coding: utf-8

translations = {
    "volume": {
        "pt": "Volume",
        "es": "Volumen",
        "en": "Volume"
    },
    "number": {
        "pt": u"Número",
        "es": "Numero",
        "en": "Number"
    },
    "pages": {
        "pt": u"Páginas",
        "es": "Paginas",
        "en": "Pages"
    },
    "supplement": {
        "pt": "Suplemento",
        "es": "Suplemento",
        "en": "Supplement"
    },
    "suppl": {
        "pt": "supl",
        "es": "supl",
        "en": "suppl"
    },
    "article number": {
        "pt": "Número do artigo",
        "es": "Numero del articulo",
        "en": "Article number"
    },
}



# coding: utf-8

import re
from datetime import datetime

from legendarium.utils import translations

NUMBERS = re.compile(r"[^0-9]")
FORMAT_PREFIX = re.compile(r"%.")
SPACES = re.compile(r" +")


def get_numbers(value):
    """
    Get just numbers in a text.
    """
    if not value:
        return ''

    return NUMBERS.sub("", value)


def parse_date(value):

    try:
        dt = datetime.strptime(value, '%Y-%m-%d')
        return dt.isoformat()[:10]
    except:
        try:
            dt = datetime.strptime(value, '%Y-%m')
            return dt.isoformat()[:7]
        except:
            try:
                dt = datetime.strptime(value, '%Y')
                return dt.isoformat()[:4]
            except:
                raise ValueError(u'Probably not a valid year')


class CitationFormatter:

    def __init__(self, title='', short_title='', pubdate='', volume='', number='',
                 fpage='', lpage='', elocation='', suppl=''):

        """
        Create a instance of Legendarium

        arguments:
        title -- Full version of the journal title
        short_title -- short version of the journal title
        pubdata -- a valid ISO date YYYY-MM-DD (no hour, minutes and seconds accepted)

        Keyword arguments:
        volume -- issue volume
        number -- issue number
        suppl -- supplement identification
        """

        self._title = title.strip() if title else ''
        self._short_title = short_title.strip() if short_title else ''
        self._pubdate = parse_date(pubdate)
        self._volume = str(volume).strip() if volume else ''
        self._number = str(number).strip() if number else ''
        self._suppl = str(suppl).strip() if suppl else ''
        self._fpage = str(fpage).strip() if fpage else ''
        self._lpage = str(lpage).strip() if lpage else ''
        self._elocation = str(elocation).strip() if elocation else ''

    def __repr__(self):
        return "%s.%s(%s, %s, %s, %s, %s, %s, %s, %s, %s)" % (
            self.__class__.__module__,
            self.__class__.__qualname__,
            self._title,
            self._short_title,
            self._pubdate,
            self._volume,
            self._number,
            self._suppl,
            self._fpage,
            self._lpage,
            self._elocation
        )

    @property
    def title(self):

        return self._title

    @property
    def short_title(self):

        return self._short_title

    @property
    def yearpubdata(self):

        return self._pubdate[0:4]

    @property
    def pubdate(self):

        return self._pubdate

    @property
    def volume(self):

        return self._volume

    @property
    def number(self):

        return self._number

    @property
    def suppl(self):

        if self._suppl == '0':
            return ''

        return self._suppl

    def issue(self):
        """
        This function returns a string with a short version of the issue identification

        Example 1:
            self.volume: 10
            self.number: 12
            return 10(12)

        Example 2:
            self.volume: 10
            return 10

        Example 3:
            self.number: 12
            return (12)

        Example 4:
            self.volume: 10
            self.number: 12
            self.suppl: 1
            return 10(12) suppl. 1

        """

    @property
    def fpage(self):

        return self._fpage

    @property
    def lpage(self):

        return self._lpage

    @property
    def pages(self):

        pages = [i for i in sorted([self.fpage, self.lpage]) if i]

        if pages:
            return "-".join(pages)

        if self.elocation:
            return self.elocation

        return ''

    @property
    def elocation(self):

        return self._elocation

    @property
    def rawformat(self):

        data = (
            self._title,
            self._short_title,
            self._pubdate,
            self._volume,
            self._number,
            self._suppl,
            self._fpage,
            self._lpage,
            self._elocation
        )

        return ', '.join([i for i in data if i])

    def format(self, fmt_spec=''):

        return self.__format__(fmt_spec)

    def __format__(self, fmt_spec=''):

        FORMAT_PATTERNS = {
            '%T': self.title,
            '%t': self.short_title,
            '%Y': self.yearpubdata,
            '%v': self.volume,
            '%n': self.number,
            '%s': self.suppl,
            '%f': self.fpage,
            '%l': self.lpage,
            '%p': self.pages,
            '%e': self.elocation,
            '%d': self.pubdate
        }

        itens = FORMAT_PREFIX.findall(fmt_spec)

        for item in itens:
            if item in FORMAT_PATTERNS:
                fmt_spec = fmt_spec.replace(item, FORMAT_PATTERNS[item])
            else:
                raise ValueError('Pattern %s not found in %s' % [item, str([i for i in FORMAT_PATTERNS])])

        return fmt_spec.strip()


def very_short_format(pubdate='', volume='', number='', suppl='', language='en'):
    """
    Return a very short version of a bibliografic legend, according to the given
    parameters. Normaly used to identify the Issue Label.

    Keyword arguments:
    title -- Full version of the journal title
    short_title -- short version of the journal title
    pubdata -- a valid ISO date YYYY-MM-DD (no hour, minutes and seconds accepted)
    volume -- issue volume
    number -- issue number
    suppl -- supplement identification

    return: (string)
    67(9) suppl. 3 - 2011
    """

    template = ['%Y,']

    vn = ''
    if volume:
        vn += '%v'

    if number:
        vn += '(%n)'

    template.append(vn)

    if suppl:
        template.append(translations['suppl'][language]+'. %s')

    output = CitationFormatter(
        title='',
        short_title='',
        pubdate=pubdate,
        volume=volume,
        number=number,
        fpage='',
        lpage='',
        elocation='',
        suppl=suppl
    )

    return output.format(' '.join(template))


def short_format(title='', short_title='', pubdate='', volume='', number='', suppl=''):
    """
    Return a short version of a bibliografic legend, according to the given
    parameters.

    Keyword arguments:
    title -- Full version of the journal title
    short_title -- short version of the journal title
    pubdata -- a valid ISO date YYYY-MM-DD (no hour, minutes and seconds accepted)
    volume -- issue volume
    number -- issue number
    suppl -- supplement identification

    return (string) Rev.Mal-Estar Subj, 2011 67(9) suppl. 3
    """

    template = ['%t, %Y']

    vn = ''
    if volume:
        vn += '%v'

    if number:
        vn += '(%n)'

    template.append(vn)

    if suppl:
        template.append('suppl %s')

    output = CitationFormatter(
        title=title,
        short_title=short_title,
        pubdate=pubdate,
        volume=volume,
        number=number,
        fpage='',
        lpage='',
        elocation='',
        suppl=suppl
    )

    return output.format(' '.join(template))


def descriptive_format(title='', short_title='', pubdate='', volume='', number='', fpage='', lpage='', elocation='', suppl='', language='en'):
    """
    Return a short version of a bibliografic legend, according to the given
    parameters.

    Keyword arguments:
    title -- Full version of the journal title
    short_title -- short version of the journal title
    pubdata -- a valid ISO date YYYY-MM-DD (no hour, minutes and seconds accepted)
    volume -- issue volume
    number -- issue number
    suppl -- supplement identification

    return: (string)
    Revista Mal-Estar Subjetivo, 2011, volume: 67, number: 9, supplement: 3, pages: 154-200
    """

    template = ['%T, %Y']

    if volume:
        template.append(translations['volume'][language]+': %v')

    if number:
        template.append(translations['number'][language]+': %n')

    if suppl:
        if suppl == '0':
            template[-1] += ' '+translations['supplement'][language]
        else:
            template[-1] += ' '+translations['supplement'][language]+' %s'

    if fpage or lpage:
        template.append(translations['pages'][language]+': %p')

    if elocation:
        if (fpage or lpage):
            template.pop()
        template.append(translations['article number'][language]+': %e')

    output = CitationFormatter(
        title=title,
        short_title=short_title,
        pubdate=pubdate,
        volume=volume,
        number=number,
        fpage=fpage,
        lpage=lpage,
        elocation=elocation,
        suppl=suppl
    )

    return output.format(', '.join(template))


def descriptive_html_format(title='', short_title='', pubdate='', volume='', number='', fpage='', lpage='', elocation='', suppl='', language='en'):
    """
    Return a short version of a bibliografic legend, according to the given
    parameters.

    Keyword arguments:
    title -- Full version of the journal title
    short_title -- short version of the journal title
    pubdata -- a valid ISO date YYYY-MM-DD (no hour, minutes and seconds accepted)
    volume -- issue volume
    number -- issue number
    suppl -- supplement identification
    fpage -- document first page
    lpage -- document last page
    elocation -- document elocation id

    return:
    <div class="biblio_label">
      <span class="title">Revista Mal-Estar Subjetivo</span>
      <span class="year">2011</span>
      <span class="prefix volume">volume:</span>
      <span class="value volume">67</span>
      <span class="prefix number">number:</span>
      <span class="value number">9</span
      <span class="prefix supplement">supplement:</span>
      <span class="value supplement">3</span
      <span class="prefix pages">article number:</span>
      <span class="value pages">e00120416</span>
    </div>
    """

    template = []
    template.append('<div class="biblio_label">')
    template.append('<span class="title">%T</span>')
    template.append('<span class="year">%Y</span>')

    if volume:
        template.append('<span class="prefix volume">'+translations['volume'][language]+':</span> <span class="value volume">%v</span>')

    if number:
        template.append('<span class="prefix number">'+translations['number'][language]+':</span> <span class="value number">%n</span>')

    if suppl:
        template.append('<span class="prefix supplement">'+translations['supplement'][language]+'</span> <span class="value supplement">%s</span>')

    if fpage or lpage:
        template.append('<span class="prefix pages">'+translations['pages'][language]+':</span> <span class="value pages">%p</span>')

    if elocation:
        if (fpage or lpage):
            template.pop()
        template.append('<span class="prefix pages">'+translations['article number'][language]+':</span> <span class="value pages">%e</span>')

    template.append('</div>')

    output = CitationFormatter(
        title=title,
        short_title=short_title,
        pubdate=pubdate,
        volume=volume,
        number=number,
        fpage=fpage,
        lpage=lpage,
        elocation=elocation,
        suppl=suppl
    )

    return output.format(''.join(template))


def descriptive_short_format(title='', short_title='', pubdate='', volume='', number='', suppl='', language='en'):
    """
    Return a short version of a bibliografic legend, according to the given
    parameters.

    Keyword arguments:
    title -- Full version of the journal title
    short_title -- short version of the journal title
    pubdata -- a valid ISO date YYYY-MM-DD (no hour, minutes and seconds accepted)
    volume -- issue volume
    number -- issue number
    suppl -- supplement identification

    return: (string)
    Revista Mal-Estar Subjetivo, 2011, Volume: 67, Number: 9, Supplement: 3
    """

    template = ['%T, %Y']

    if volume:
        template.append(translations['volume'][language]+': %v')

    if number:
        template.append(translations['number'][language]+': %n')

    if suppl:
        if suppl == '0':
            template[-1] += ' '+translations['supplement'][language]
        else:
            template[-1] += ' '+translations['supplement'][language]+' %s'

    output = CitationFormatter(
        title=title,
        short_title=short_title,
        pubdate=pubdate,
        volume=volume,
        number=number,
        fpage='',
        lpage='',
        elocation='',
        suppl=suppl
    )

    return output.format(', '.join(template))


def descriptive_html_short_format(title='', short_title='', pubdate='', volume='', number='', suppl='', language='en'):
    """
    Return a short version of a bibliografic legend, according to the given
    parameters.

    Keyword arguments:
    title -- Full version of the journal title
    short_title -- short version of the journal title
    pubdata -- a valid ISO date YYYY-MM-DD (no hour, minutes and seconds accepted)
    volume -- issue volume
    number -- issue number
    suppl -- supplement identification

    return:
    <div class="biblio_label">
      <span class="title">Revista Mal-Estar Subjetivo</span>
      <span class="year">2011</span>
      <span class="prefix volume">volume:</span>
      <span class="value volume">67</span>
      <span class="prefix number">number:</span>
      <span class="value number">9</span
      <span class="prefix supplement">supplement:</span>
      <span class="value supplement">3</span
    </div>
    """

    template = []
    template.append('<div class="biblio_label">')
    template.append('<span class="title">%T</span>')
    template.append('<span class="year">%Y</span>')

    if volume:
        template.append('<span class="prefix volume">'+translations['volume'][language]+':</span> <span class="value volume">%v</span>')

    if number:
        template.append('<span class="prefix number">'+translations['number'][language]+':</span> <span class="value number">%n</span>')

    if suppl:
        template.append('<span class="prefix supplement">'+translations['supplement'][language]+'</span> <span class="value supplement">%s</span>')

    template.append('</div>')

    output = CitationFormatter(
        title=title,
        short_title=short_title,
        pubdate=pubdate,
        volume=volume,
        number=number,
        fpage='',
        lpage='',
        elocation='',
        suppl=suppl
    )

    return output.format(''.join(template))


def descriptive_very_short_format(pubdate='', volume='', number='', suppl='', language='en'):
    """
    Return a short version of a bibliografic legend, according to the given
    parameters.

    Keyword arguments:
    title -- Full version of the journal title
    short_title -- short version of the journal title
    pubdata -- a valid ISO date YYYY-MM-DD (no hour, minutes and seconds accepted)
    volume -- issue volume
    number -- issue number
    suppl -- supplement identification

    return: (string)
    2011, Volume: 67, Number: 9, Supplement: 3
    """

    template = ['%Y']

    if volume:
        template.append(translations['volume'][language]+': %v')

    if number:
        template.append(translations['number'][language]+': %n')

    if suppl:
        if suppl == '0':
            template[-1] += ' '+translations['supplement'][language]
        else:
            template[-1] += ' '+translations['supplement'][language]+' %s'

    output = CitationFormatter(
        title='',
        short_title='',
        pubdate=pubdate,
        volume=volume,
        number=number,
        fpage='',
        lpage='',
        elocation='',
        suppl=suppl
    )

    return output.format(', '.join(template))


def descriptive_html_very_short_format(pubdate='', volume='', number='', suppl='', language='en'):
    """
    Return a short version of a bibliografic legend, according to the given
    parameters.

    Keyword arguments:
    title -- Full version of the journal title
    short_title -- short version of the journal title
    pubdata -- a valid ISO date YYYY-MM-DD (no hour, minutes and seconds accepted)
    volume -- issue volume
    number -- issue number
    suppl -- supplement identification

    return:
    <div class="biblio_label">
      <span class="title">Revista Mal-Estar Subjetivo</span>
      <span class="year">2011</span>
      <span class="prefix volume">volume:</span>
      <span class="value volume">67</span>
      <span class="prefix number">number:</span>
      <span class="value number">9</span
      <span class="prefix supplement">supplement:</span>
      <span class="value supplement">3</span
    </div>
    """

    template = []
    template.append('<div class="biblio_label">')
    template.append('<span class="year">%Y</span>')
    if volume:
        template.append('<span class="prefix volume">'+translations['volume'][language]+':</span> <span class="value volume">%v</span>')

    if number:
        template.append('<span class="prefix number">'+translations['number'][language]+':</span> <span class="value number">%n</span>')

    if suppl:
        template.append('<span class="prefix supplement">'+translations['supplement'][language]+'</span> <span class="value supplement">%s</span>')

    template.append('</div>')

    output = CitationFormatter(
        title='',
        short_title='',
        pubdate=pubdate,
        volume=volume,
        number=number,
        fpage='',
        lpage='',
        elocation='',
        suppl=suppl
    )

    return output.format(''.join(template))



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [
    # TODO: put package requirements here
]

test_requirements = [
    # TODO: put package test requirements here
]

setup(
    name='legendarium',
    version='1.2.2',
    description="Python library to handle SciELO's bibliographic legend",
    long_description=readme + '\n\n' + history,
    author="Jamil Atta Junior",
    author_email='jamil.atta@scielo.org',
    url='https://github.com/scieloorg/legendarium',
    packages=[
        'legendarium',
    ],
    package_dir={'legendarium':
                 'legendarium'},
    include_package_data=True,
    install_requires=requirements,
    license="BSD license",
    zip_safe=False,
    keywords='legendarium',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
    ],
    test_suite='tests',
    tests_require=test_requirements
)
